Value

Enum Value 

pub enum Value<'a, Spec: Specification = Raw> {
    SingleLine {
        inner: Option<Cow<'a, str>>,
        _spec: PhantomData<Spec>,
    },
    MultiLine {
        inner: Vec<Option<Cow<'a, str>>>,
        _spec: PhantomData<Spec>,
    },
}
The value of an Attribute. Since only some values contain multiple lines and single line values do not require additional heap allocation, an Enum is used to represent both variants.

Variants



SingleLine

A single line value.

Example

let object = parse_object("
name:           ACME Company

")?;
let value = Value::new_single("ACME Company");
assert_eq!(object[0].value, value);

Fields

inner: Option<Cow<'a, str>>

The value.

_spec: PhantomData<Spec>

The values specification.



MultiLine

A value spanning over multiple lines.

Example

let object = parse_object("
remarks:        Packet Street 6
                128 Series of Tubes
                Internet

")?;
let value: Value = vec!["Packet Street 6", "128 Series of Tubes", "Internet"].into();
assert_eq!(object[0].value, value);

Fields

inner: Vec<Option<Cow<'a, str>>>

The value.

_spec: PhantomData<Spec>

The values specification.

Implementations

Source

impl<'a, Spec: Specification> Value<'a, Spec>

pub fn lines(&self) -> usize

The number of lines contained.

Examples

A value with a single line.

let value = Value::new_single("ACME Company");
assert_eq!(value.lines(), 1);

A value with multiple lines.

let value: Value = vec!["Packet Street 6", "128 Series of Tubes", "Internet"].into();
assert_eq!(value.lines(), 3);
pub fn with_content(&self) -> Vec<&str>

The lines that contain content and are non empty.

Example
let remarks = parse_object("
remarks:        I have lots
                 
                to say.

")?;
assert_eq!(remarks[0].value.with_content(), vec!["I have lots", "to say."]);
pub fn is_empty(&self) -> bool

Returns true if the value is empty.

Example
let remarks = parse_object("
remarks:

")?;
assert_eq!(remarks[0].value.is_empty(), true);
pub fn into_owned(self) -> Value<'static, Spec>

Convert this value into an owned ('static) version.

Source

impl Value<'static, Raw>

pub fn new_single<V>(value: V) -> Self
where V: Into<String>,

Create a single line value. Empty values are coerced to None.

pub fn new_multi<I, V>(values: I) -> Self
where I: IntoIterator<Item = V>, V: Into<String>,

Create a multi line value. Empty values are coerced to None.

Panics

If the given iterator contains less than two values.