Attribute

Struct Attribute 

pub struct Attribute<'a, Spec: Specification = Raw> {
    pub name: Name<'a, Spec>,
    pub value: Value<'a, Spec>,
}
An attribute of an Object.

Example

let object = parse_object("
name:           ACME Company

")?;
let attribute = Attribute::new("name", "ACME Company");
assert_eq!(object[0], attribute);

Fields

name: Name<'a, Spec>

The name of the attribute.

value: Value<'a, Spec>

The value of the attribute.

Implementations

Source

impl<'a, Spec: Specification> Attribute<'a, Spec>

pub fn new<N, V>(name: N, value: V) -> Self
where N: Into<Name<'a, Spec>>, V: Into<Value<'a, Spec>>,

Create a new attribute.

pub fn validate<TargetSpec: Specification>(&self) -> Result<(), AttributeError>

Validate that the attribute conforms to a target specification.

Errors

Returns an AttributeError if the attribute does not conform to the target specification.

pub fn into_spec<TargetSpec: Specification>( self, ) -> Result<Attribute<'a, TargetSpec>, AttributeError>

Convert the attribute into a target specification.

Errors

Returns an AttributeError if the attribute does not conform to the target specification.

pub fn into_owned(self) -> Attribute<'static, Spec>

Convert this attribute into an owned ('static) variant.