pub struct ObjectValidationError { /* private fields */ }Expand description
Contains all attribute validation errors for an Object.
Implementations
Sourceimpl ObjectValidationError
impl ObjectValidationError
Sourcepub fn iter_errors(&self) -> impl Iterator<Item = &AttributeError>
pub fn iter_errors(&self) -> impl Iterator<Item = &AttributeError>
Iterate over the attribute errors.
Sourcepub fn iter_indexed(&self) -> impl Iterator<Item = (usize, &AttributeError)>
pub fn iter_indexed(&self) -> impl Iterator<Item = (usize, &AttributeError)>
Iterate over attribute errors together with the index of the offending attribute.
Sourcepub fn into_errors(self) -> Vec<(usize, AttributeError)>
pub fn into_errors(self) -> Vec<(usize, AttributeError)>
Return attribute errors together with the index of the offending attribute.