pub struct Attribute<'a, Spec: Specification = Raw> {
pub name: Name<'a, Spec>,
pub value: Value<'a, Spec>,
}Expand description
Fields
name: Name<'a, Spec>The name of the attribute.
value: Value<'a, Spec>The value of the attribute.
Implementations
Sourceimpl<'a, Spec: Specification> Attribute<'a, Spec>
impl<'a, Spec: Specification> Attribute<'a, Spec>
Sourcepub fn validate<TargetSpec: Specification>(&self) -> Result<(), AttributeError>
pub fn validate<TargetSpec: Specification>(&self) -> Result<(), AttributeError>
Validate that the attribute conforms to a target specification.
Errors
Returns an AttributeError if the attribute does not conform to the target specification.
Sourcepub fn into_spec<TargetSpec: Specification>(
self,
) -> Result<Attribute<'a, TargetSpec>, AttributeError>
pub fn into_spec<TargetSpec: Specification>( self, ) -> Result<Attribute<'a, TargetSpec>, AttributeError>
Convert the attribute into a target specification.
Errors
Returns an AttributeError if the attribute does not conform to the target specification.
Sourcepub fn into_owned(self) -> Attribute<'static, Spec>
pub fn into_owned(self) -> Attribute<'static, Spec>
Convert this attribute into an owned ('static) variant.